#!/usr/bin/env python
# -*- coding: utf-8 -*-
import re
import silabeador


consonantes = {'w': 'b', 'v': 'b', 'z': 'θ', 'x': 'ks', 'j': 'x', 'ch':'tʃ',
               'ñ': 'ɲ',
               'qu': 'k', 'll': 'ʎ', 'ch':'tʃ', 'r': 'ɾ', 'ɾɾ': 'r',
               'sɾ': 'sr', 'lɾ': 'lr', 'nɾ': 'nr',
               'ce': 'θe', 'cé': 'θe', 'cë': 'θe',
               'ci': 'θi', 'cí': 'θi', 'cï': 'θi', 'cj': 'θi',
               'c': 'k', 'h':''}
diacriticos = {'á': 'a', 'à': 'a', 'ä': 'a',
               'é': 'e', 'è': 'e', 'ë': 'e',
               'í': 'i', 'ì': 'i', 'ï': 'i',
               'ó': 'o', 'ò': 'o', 'ö': 'o',
               'ú': 'u', 'ù': 'u', 'ü': 'u'}




def transcribe(palabra):
    palabra = palabra.lower()
    silabas_des = silabeador.silabas(palabra)
    silabas = silabas_des.silabas
    for idx, silaba in enumerate(silabas):
        if silaba.endswith('y'):
            silaba = silaba.replace('y','i')
        for letras in consonantes:
            if letras in silaba:
                silaba  = silaba.replace(letras, consonantes[letras])
        if 'g' in silaba:
            for reg in [[r'g([eiéíiëï])', rf'x\1'],
                        [r'g[u]([eiéíëï])', rf'g\1']]:
                silaba = re.sub(reg[0], reg[1], silaba)
        if 'gü' in silaba:
            silaba = silaba.replace('gü', 'gw')
        if re.search('[aeiouáéíóú]{2,}', silaba):
            silaba = re.sub(r'([aeiouáééó])i', rf'\1j', silaba)
            silaba = re.sub(r'([aeiouáééó])u', rf'\1w', silaba)
        if re.search('[ui][aeiouáééiíóú]', silaba):
            silaba = re.sub(r'i([aeouáééiíóú])', rf'j\1', silaba)
            silaba = re.sub(r'u([aeioáééiíóú])', rf'w\1', silaba)
        for letra in diacriticos:
            if letra in silaba:
                silaba = silaba.replace(letra, diacriticos[letra])
        silabas[idx] = silaba
    if silabas[0].startswith('ɾ'):
        silabas[0] = re.sub('^ɾ', 'r', silabas[0])
    silabas[silabas_des.tonica] = f"'{silabas[silabas_des.tonica]}"
    return silabas




import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

install_requires = ['silabeador']


# This call to setup() does all the work
setup(
    name="fonemas",
    version="1.0.4-2",
    python_requires='>=3.5',
    description="Phonologic transcription of Spanish",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/fsanzl/fonemas",
    project_urls={
        'Source': 'https://github.com/fsanzl/fonemas/',
        'Tracker': 'https://github.com/fsanzl/fonemas/issues',
    },
    author="Fernando Sanz-Lázaro",
    author_email="fsanzl@gmail.com",
    license="LGPL",
    classifiers=[
        "License :: OSI Approved :: GNU Lesser General Public License v2 or later (LGPLv2+)",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.5",
        "Natural Language :: Spanish",
    ],
    packages=["fonemas"],
    include_package_data=True,
    entry_points={
        "console_scripts": [
            "fonemas=fonemas.__main__:main",
        ]
    },
)
